@@ -35,7 +35,6 @@ class PolyMaker:
             "acrylates": "[CH2]=[C][C](=[O])",
             "double_bond": "C=C",
             "vinyls": "[CH2]=[CH!$(CC=O)]",
-            "imides": "[#8:3]([#6:4](=[#8:5]))([#6:6](=[#8:7]))",
             "double_bond_secondary": "[CH]=[CH]",
             "double_bond_tertiary": "C[C]=[C!$([CH])]C",
             "double_bond_quaternary": "C[C!$([CH])]=[C!$([CH])]C",
@@ -102,7 +101,7 @@ class PolyMaker:
                 "infinite_chain": "to complete",
             },
         }
-        self.__verison__ = "0.1.7.0"
+        self.__verison__ = "0.1.7.1"
 
     @staticmethod
     def checksmile(smi: str) -> Union[str, None]:
@@ -128,7 +127,9 @@ class PolyMaker:
         return smi
 
     @staticmethod
-    def get_monomers(smi: str, stereochemistry: bool = True) -> List[str]:
+    def get_monomers(
+        smi: str, stereochemistry: bool = True, sort_by_mw: bool = True
+    ) -> List[str]:
         """Convert a string of monomers into a list of monomers.
 
         The input string must contain monomer SMILES seperated by ".". Each monomer is checked for validity.
@@ -139,7 +140,8 @@ class PolyMaker:
             SMILES strings seperated by "." if multiple SMILES.
         stereochemistry : bool, optional
             Whether or not to retain stereochemistry in SMILES strings, by default False
-
+        stereochemistry : bool, optional
+            Sorts monomers by their molecular weight, default True
         Returns
         -------
         List[str]
@@ -173,6 +175,13 @@ class PolyMaker:
         # Check to see if there are any bad smiles in flattened list
         if any([item == "" for sublist in monomers for item in sublist]):
             monomers == None
+        # Sort by MW
+        if sort_by_mw == True:
+            dict_mw_smile = {
+                Descriptors.ExactMolWt(Chem.MolFromSmiles(Chem.CanonSmiles(s))): s
+                for s in monomers
+            }
+            monomers = tuple(dict_mw_smile[k] for k in sorted(dict_mw_smile))
 
         return monomers
 
@@ -383,7 +392,8 @@ class PolyMaker:
 
         if "index" in df_return_mapped.columns:
             df_return_mapped = df_return_mapped.drop(columns=["index"])
-        df_return_mapped = df_return_mapped.drop(columns=["replicate_structures"])
+        if "replicate_structures" in df_return_mapped.columns:
+            df_return_mapped = df_return_mapped.drop(columns=["replicate_structures"])
         df_return_mapped = df_return_mapped.reset_index(drop=True)
 
         return df_return_mapped
